/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Klasse zur Verwaltung einer Auswahlliste
*/
function Auswahlliste() {
    Object.defineProperty(this, 'node', {
        enumerable: true,
        value: ScoTools.createHtml('ul', null, { 'class': 'auswahlliste' })
    });
    this._items = [];
}

// Alle Listeneinträge
Auswahlliste.prototype._items = [];

// UL-Element der Liste
Auswahlliste.prototype.node = null;

/**
* Listeneintrag hinzufügen
* @return undefined
*/
Auswahlliste.prototype.add = function(
    text,       // Für Benutzer sichtbarer Text
    id          // Interne ID
) {
    for (var z = 0; z < this._items.length; ++z) {
        if (this._items[z].id == id) {
            this._items[z].node.firstChild.textContent = text;
            return;
        }
    }
    var node = ScoTools.createHtml('li', this.node);
    var self = this;
    ScoTools.createHtml('a', node, { 'href': '#', 'role': 'button' }, text).addEventListener('click', function(ev) {
        ev.preventDefault();
        ev.stopPropagation();
        self.procClick(id);
    });
    this._items.push({ 'id': id, 'node': node });
}

/**
* Listeneintrag entfernen
* @return undefined
*/
Auswahlliste.prototype.remove = function(
    id      // Interne ID
) {
    this._items = this._items.filter(function(el) {
        if (el.id == id) {
            el.node.parentNode.removeChild(el.node);
            return false;
        } else
            return true;
    });
}

/**
* Alle Listeneinträge entfernen
* @return undefined
*/
Auswahlliste.prototype.clear = function() {
    this._items = [];
    this.node.innerHTML = '';
}

/**
* Anzahl an Listeneinträgen ermitteln
* @return Number    Anzahl an Einträgen
*/
Auswahlliste.prototype.getLength = function() {
    return this._items.length;
}

// Was soll passieren, wenn ein Eintrag angeklickt wird (Parameter ist die interne ID des angeklickten Eintrags)
Auswahlliste.prototype.onclick = null;

/**
* Auf Anklicken reagieren
* @return undefined
*/
Auswahlliste.prototype.procClick = function(
    id      // Interne ID des angeklickten Elements
) {
    if (typeof this.onclick == 'function');
        this.onclick.call(this, id);
}

/**
* Klassenname für Eintrag mit interner ID id auf className setzen
* @return undefined
*/
Auswahlliste.prototype.setClass = function(
    id,         // Interne ID
    className   // Gewünschter Klassenname
) {
    for (var z = 0; z < this._items.length; ++z) {
        if (this._items[z].id == id) {
            this._items[z].node.firstChild.className = className;
            return;
        }
    }
}

/**
* Klassenname für Eintrag mit interner ID id auf className setzen und den Klassenname aller anderen Elemente ggf. zurücksetzen
* @return undefined
*/
Auswahlliste.prototype.setOnlyClass = function(
    id,         // Interne ID
    className   // Gewünschter Klassenname
) {
    for (var z = 0; z < this._items.length; ++z) {
        if (this._items[z].id == id)
            this._items[z].node.firstChild.className = className;
        else if (this._items[z].node.firstChild.className)
            this._items[z].node.firstChild.className = '';
    }
}
